# navalmartin_mir_vision_utils

Various utilities for working with images in the _mir_ project. 

## Acknowledgements 

The project incorporates the following repositories

- ```image-quality``` https://github.com/ocampor/image-quality (for BRISQUE)
- ```imutils```: https://github.com/PyImageSearch/imutils (for various utilities with OpenCV)

## Dependencies

- torch
- torchvision
- numpy
- dataclasses
- Pillow
- matplotlib
- opencv-python
- scipy
- scikit-image
- libsvm

## Installation

Installing the utilities via ```pip```

```
pip install -navalmartin-mir-vision-utils
```

For a specific version use

```
pip install -navalmartin-mir-vision-utils==x.x.x
```

You can uninstall the project via

```commandline
pip3 uninstall navalmartin_mir_vision_utils
```

## How to use
